from typing import Union

import pint

METER = 'meter'
CENTIMETER = 'centimeter'
MILLIMETER = 'millimeter'
KILOMETER = 'kilometer'
INCH = 'inch'
HAND = 'hand'
FOOT = 'foot'
YARD = 'yard'
MILE = 'mile'
LIGHT_YEAR = 'light_year'
ASTRONOMICAL_UNIT = 'astronomical_unit'
PARSEC = 'parsec'
NAUTICAL_MILE = 'nautical_mile'
ANGSTROM = 'angstrom'
MICRON = 'micron'
PLANCK_LENGTH = 'planck_length'
