from typing import Union

import pint

SECONDS = "seconds"
MINUTES = "minutes"
HOURS = "hours"
DAYS = "days"
WEEKS = "weeks"
FORTNIGHTS = "fortnights"
YEARS = "years"
MONTHS = "months"
CENTURIES = "centuries"
MILLENNIUMS = "millenniums"
